diff src/connection.h @ 10272:bf1ebc8f3bf3

[gaim-migrate @ 11421] Change "Signoff" to "Log Out" in a few user-visible places. I <dinky little heart> consistency. committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Sat, 27 Nov 2004 17:07:28 +0000
parents 2f41f462ab4e
children 5879593a6a10
line wrap: on
line diff
--- a/src/connection.h	Sat Nov 27 16:09:31 2004 +0000
+++ b/src/connection.h	Sat Nov 27 17:07:28 2004 +0000
@@ -93,7 +93,7 @@
 	gboolean is_auto_away;       /**< Whether or not it's auto-away.     */
 
 	gboolean wants_to_die;	     /**< Wants to Die state.  This is set
-	                                  when the user chooses to sign off,
+	                                  when the user chooses to log out,
 	                                  or when the protocol is
 	                                  disconnected and should not be
 	                                  automatically reconnected
@@ -127,9 +127,9 @@
 void gaim_connection_destroy(GaimConnection *gc);
 
 /**
- * Signs a connection on.
+ * Logs in to this connection.
  *
  * @param gc The connection to sign on.
  *
  * @see gaim_connection_disconnect()
  */
@@ -143,9 +143,9 @@
 void gaim_connection_register(GaimConnection *gc);
 
 /**
- * Signs a connection off.
+ * Logs out of this connection.
  *
  * @param gc The connection to sign off.
  *
  * @see gaim_connection_connect()
  */
@@ -127,9 +127,9 @@
  *
- * @param gc The connection to sign on.
+ * @param gc The connection to log in.
  *
  * @see gaim_connection_disconnect()
@@ -143,9 +143,9 @@
  *
- * @param gc The connection to sign off.
+ * @param gc The connection to log out.
  *
  * @see gaim_connection_connect()